// +build !dev

package main

import (
	"fmt"
	"net/http"
	"path"

	"github.com/julienschmidt/httprouter"
)

//go:generate go-bindata -ignore "\\.go|\\.less" -pkg "main" -o "bindata.go" htdocs/...
//go:generate go fmt bindata.go

func init() {
	Router().GET("/", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset("htdocs/index.html"); err != nil {
			fmt.Fprintf(w, "{\"errmsg\":%q}", err)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/auth", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset("htdocs/index.html"); err != nil {
			fmt.Fprintf(w, "{\"errmsg\":%q}", err)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/grades", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset("htdocs/index.html"); err != nil {
			fmt.Fprintf(w, "{\"errmsg\":%q}", err)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/surveys", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset("htdocs/index.html"); err != nil {
			fmt.Fprintf(w, "{\"errmsg\":%q}", err)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/surveys/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset("htdocs/index.html"); err != nil {
			fmt.Fprintf(w, "{\"errmsg\":%q}", err)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/users", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset("htdocs/index.html"); err != nil {
			fmt.Fprintf(w, "{\"errmsg\":%q}", err)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/users/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset("htdocs/index.html"); err != nil {
			fmt.Fprintf(w, "{\"errmsg\":%q}", err)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/css/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		w.Header().Set("Content-Type", "text/css")
		if data, err := Asset(path.Join("htdocs", r.URL.Path)); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/fonts/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset(path.Join("htdocs", r.URL.Path)); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/img/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset(path.Join("htdocs", r.URL.Path)); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/js/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		w.Header().Set("Content-Type", "text/javascript")
		if data, err := Asset(path.Join("htdocs", r.URL.Path)); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/views/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		w.Header().Set("Content-Type", "text/html")
		if data, err := Asset(path.Join("htdocs", r.URL.Path)); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})
}

func sanitizeStaticOptions() error {
	return nil
}
